@@ -8,6 +8,7 @@ import stat
 import importlib
 from fnmatch import fnmatch
 from functools import singledispatch
+from functools import total_ordering
 
 from pysyte.types.lists import flatten
 
@@ -46,7 +47,8 @@ class PathAssertions:
 from path import Path as PPath  # pylint: disable=wrong-import-order,wrong-import-position
 
 
-class NonePath(object):
+@total_ordering
+class NonePath:
     def __init__(self, string=None):
         self.string = string if string else ''
         self.proxy = DirectPath(self.string)
@@ -66,6 +68,8 @@ class NonePath(object):
         return not other
 
     def __lt__(self, other):
+        if self.string and other:
+            return str(self) < str(other)
         return bool(other)
 
     def __contains__(self, _):
@@ -93,6 +97,7 @@ class NonePath(object):
         return getattr(self.proxy, name, None)
 
 
+@total_ordering
 class DotPath(PPath):
     """Some additions to the classic path class"""
     # pylint: disable=abstract-method
@@ -134,9 +139,6 @@ class DotPath(PPath):
     def name(self):
         return str(super().name)
 
-    def isroot(self):
-        return str(self) == '/'
-
     def parent_directory(self):
         if self.isroot():
             return None
@@ -146,8 +148,6 @@ class DotPath(PPath):
         if self.isroot():
             return []
         parent = self.parent
-        if not parent:
-            return []
         return [parent] + parent.parent_directories()
 
     def directory(self):
@@ -222,15 +222,6 @@ class DotPath(PPath):
         parts = super().split(separator, maxsplit)
         parts[0] = makepath(parts[0] if parts[0] else '/')
         return parts
-        root, *names = self.splitall()
-        path_ = makepath(str(root))
-        result = [path_]
-        for name in names:
-            path_ = path_ / name
-            if not path_.isdir():
-                break
-            result.append(path_)
-        return result
 
     def abspath(self):
         return makepath(os.path.abspath(str(self)))
@@ -260,25 +251,6 @@ class DotPath(PPath):
         """A short path relative to self to the current working directory"""
         return self.__class__(os.getcwd()).short_relative_path_to(self)
 
-    def walk_some_dirs(self, levels=-1, pattern=None):
-        """ D.walkdirs() -> iterator over subdirs, recursively.
-
-        With the optional 'pattern' argument, this yields only
-        directories whose names match the given pattern.  For
-        example, mydir.walkdirs('*test') yields only directories
-        with names ending in 'test'.
-        """
-        if not levels:
-            yield self
-            return
-        levels -= 1
-        for child in self.dirs():
-            if pattern is None or child.fnmatch(pattern):
-                yield child
-            if levels:
-                for subsubdir in child.walk_some_dirs(levels, pattern):
-                    yield subsubdir
-
     def fnmatch_basename(self, glob):
         if glob.startswith(os.path.sep):
             glob = glob.lstrip(os.path.sep)
@@ -319,6 +291,7 @@ class DotPath(PPath):
         return None
 
     def __get_owner_not_implemented(self):
+        """Remove pylint warning"""
         pass
 
     def expand(self):
@@ -336,12 +309,22 @@ class DotPath(PPath):
     def same_path(self, other):
         return self.expand() == other.expand()
 
-    @property
-    def hidden(self):
+    def isroot(self):
+        raise NotImplementedError('Only a directory path can be a root')
+
+    def ishidden(self):
         """A 'hidden file' has a name starting with a '.'"""
         s = str(self.basename())
         return s and s[0] == '.'
 
+    def is_executable(self):
+        """Whether the path is executable"""
+        # pylint: disable=no-self-use
+        return False
+
+    def isexec(self):
+        return self.is_executable()
+
     def add_ext(self, *args):
         """Join all args as extensions
 
@@ -369,14 +352,6 @@ class DotPath(PPath):
             return makepath(self)
         return self.add_ext(extension)
 
-    def is_executable(self):
-        """Whether the path is executable"""
-        # pylint: disable=no-self-use
-        return False
-
-    def isexec(self):
-        return self.is_executable()
-
     def has_executable(self):
         """Whether the path has any executable bits set """
         executable_bits = stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH
@@ -407,14 +382,6 @@ def ext_language(ext, exts=None, simple=True):
     ext_languages = {_: languages[_] for _ in exts} if exts else languages
     return ext_languages.get(ext)
 
-def mime_language(ext, exts=None):
-    if ext == '.txt':
-        return 'txt'
-    language = ext_language(ext, exts, True)
-    if language:
-        return f'txt/{language}'
-    return ''
-
 
 del PPath
 
@@ -455,6 +422,10 @@ class FilePath(DotPath, PathAssertions):
                 for l in self.stripped_whole_lines()
                 if not l.startswith('#')]
 
+    def isroot(self):
+        """A file cannot be root of a filesystem"""
+        return False
+
     def is_executable(self):
         """Whether the file has any executable bits set"""
         return self.has_executable()
@@ -527,17 +498,11 @@ class FilePath(DotPath, PathAssertions):
         If no shebang is present, return an empty string
         """
         try:
-            try:
-                first_line = self.lines(retain=False)[0]
-            except (OSError, UnicodeDecodeError):
-                return ''
-            if first_line.startswith('#!'):
-                rest_of_line = first_line[2:].strip()
-                parts = rest_of_line.split(' ')
-                interpreter = parts[0]
-                return makepath(interpreter)
-        except IndexError:
-            pass
+            first_line = self.lines(retain=False)[0]
+        except (OSError, UnicodeDecodeError):
+            return ''
+        if first_line.startswith('#!'):
+            return first_line[2:].strip()
         return ''
 
     def mv(self, destination):  # pylint: disable=invalid-name
@@ -555,23 +520,12 @@ class FilePath(DotPath, PathAssertions):
         try:
             return self._language
         except AttributeError:
-            self._language = find_language(self, getattr(self, 'exts', None))
+            self._language = ext_language(self.ext)
         return self._language
 
     @language.setter
     def language(self, value):
-        self._langauge = value
-
-    def choose_language(self, exts):
-        self._exts = exts
-        self._language = ext_language(self.ext, exts)
-
-    def mimetype(self):
-        import magic  # pylint: disable=import-outside-toplevel
-        result = magic.from_file(str(self))
-        if result.startswith('txt'):
-            return mime_language(self.ext)
-        return result
+        self._language = value
 
 
 class DirectPath(DotPath, PathAssertions):
@@ -722,6 +676,9 @@ class DirectPath(DotPath, PathAssertions):
                 return True
         return False
 
+    def isroot(self):
+        return str(self) == '/'
+
 
 def ignore_fnmatches(ignores):
 
@@ -783,7 +740,8 @@ def _(arg):
     if os.path.isfile(arg):
         return FilePath(arg)
     if os.path.isdir(arg):
-        return DirectPath(arg)
+        string = arg if arg == '/' else arg.rstrip('/')
+        return DirectPath(string)
     v = os.path.expandvars(arg)
     u = os.path.expanduser(v)
     if arg == u:
@@ -820,11 +778,9 @@ def _(arg):
 
 def makestr(string: str):
     """Make a path from a string"""
-    if not string:
-        return ''
     if os.path.isfile(string) or os.path.isdir(string):
         return makepath(string)
-    return string
+    return NonePath(string)
 
 
 def cd(path_to):  # pylint: disable=invalid-name
@@ -919,6 +875,10 @@ def directories(strings):
     return split_directories(strings)[0]
 
 
+def root():
+    return makepath('/')
+
+
 def tmp():
     return makepath('/tmp')
 
@@ -988,11 +948,12 @@ def list_items(path_to_directory, pattern, wanted=lambda x: True):
 
     By default, every path is wanted
     """
-    if not path_to_directory:
+    path_ = makepath(path_to_directory)
+    if not path_:
         return set()
-    needed = fnmatcher(pattern, path_to_directory, wanted)
-    return [os.path.join(path_to_directory, name)
-            for name in _names_in_directory(path_to_directory)
+    needed = fnmatcher(pattern, path_, wanted)
+    return [os.path.join(path_, name)
+            for name in _names_in_directory(path_)
             if needed(name)]
 
 
@@ -1012,13 +973,7 @@ def set_files(path_to_directory, pattern):
 
 def contains_glob(path_to_directory, pattern, wanted=lambda x: True):
     """Whether the given path contains an item matching the given glob"""
-    if not path_to_directory:
-        return False
-    needed = fnmatcher(pattern, path_to_directory, wanted)
-    for name in _names_in_directory(path_to_directory):
-        if needed(name):
-            return True
-    return False
+    return any(list_items(path_to_directory, pattern, wanted))
 
 
 def contains_directory(path_to_directory, pattern):
@@ -1060,14 +1015,6 @@ def add_stars(strings):
     return [add_star(p) for p in paths_]
 
 
-def tab_complete_files(paths_, globber):
-    return tab_complete(paths_, globber, os.path.isfile)
-
-
-def tab_complete_dirs(paths_, globber):
-    return tab_complete(paths_, globber, os.path.isdir)
-
-
 def tab_complete(strings, globber=add_stars, select=os.path.exists):
     """Finish path names "left short" by bash's tab-completion
 
